Struct aws_sdk_resourcegroups::client::fluent_builders::UpdateGroup[][src]

pub struct UpdateGroup<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to UpdateGroup.

Updates the description for an existing group. You cannot update the name of a resource group.

Minimum permissions

To run this command, you must have the following permissions:

  • resource-groups:UpdateGroup

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

Don't use this parameter. Use Group instead.

Don't use this parameter. Use Group instead.

The name or the ARN of the resource group to modify.

The name or the ARN of the resource group to modify.

The new description that you want to update the resource group with. Descriptions can contain letters, numbers, hyphens, underscores, periods, and spaces.

The new description that you want to update the resource group with. Descriptions can contain letters, numbers, hyphens, underscores, periods, and spaces.