Struct aws_sdk_resourcegroups::client::fluent_builders::UpdateGroupQuery [−][src]
pub struct UpdateGroupQuery<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to UpdateGroupQuery.
Updates the resource query of a group. For more information about resource queries, see Create a tag-based group in Resource Groups.
Minimum permissions
To run this command, you must have the following permissions:
-
resource-groups:UpdateGroupQuery
Implementations
impl<C, M, R> UpdateGroupQuery<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> UpdateGroupQuery<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<UpdateGroupQueryOutput, SdkError<UpdateGroupQueryError>> where
R::Policy: SmithyRetryPolicy<UpdateGroupQueryInputOperationOutputAlias, UpdateGroupQueryOutput, UpdateGroupQueryError, UpdateGroupQueryInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<UpdateGroupQueryOutput, SdkError<UpdateGroupQueryError>> where
R::Policy: SmithyRetryPolicy<UpdateGroupQueryInputOperationOutputAlias, UpdateGroupQueryOutput, UpdateGroupQueryError, UpdateGroupQueryInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Don't use this parameter. Use Group instead.
Don't use this parameter. Use Group instead.
The name or the ARN of the resource group to query.
The name or the ARN of the resource group to query.
The resource query to determine which AWS resources are members of this resource group.
A resource group can contain either a Configuration or a
ResourceQuery, but not both.
The resource query to determine which AWS resources are members of this resource group.
A resource group can contain either a Configuration or a
ResourceQuery, but not both.