Struct aws_sdk_resourcegroups::client::Client [−][src]
pub struct Client<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
An ergonomic service client for Ardi.
This client allows ergonomic access to a Ardi-shaped service.
Each method corresponds to an endpoint defined in the service’s Smithy model,
and the request and response shapes are auto-generated from that same model.
Using a Client
Once you have a client set up, you can access the service’s endpoints
by calling the appropriate method on Client. Each such method
returns a request builder for that endpoint, with methods for setting
the various fields of the request. Once your request is complete, use
the send method to send the request. send returns a future, which
you then have to .await to get the service’s response.
Implementations
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
Constructs a fluent builder for the CreateGroup operation.
See CreateGroup for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteGroup operation.
See DeleteGroup for more information about the
operation and its arguments.
Constructs a fluent builder for the GetGroup operation.
See GetGroup for more information about the
operation and its arguments.
Constructs a fluent builder for the GetGroupConfiguration operation.
See GetGroupConfiguration for more information about the
operation and its arguments.
Constructs a fluent builder for the GetGroupQuery operation.
See GetGroupQuery for more information about the
operation and its arguments.
Constructs a fluent builder for the GetTags operation.
See GetTags for more information about the
operation and its arguments.
Constructs a fluent builder for the GroupResources operation.
See GroupResources for more information about the
operation and its arguments.
Constructs a fluent builder for the ListGroupResources operation.
See ListGroupResources for more information about the
operation and its arguments.
Constructs a fluent builder for the ListGroups operation.
See ListGroups for more information about the
operation and its arguments.
Constructs a fluent builder for the PutGroupConfiguration operation.
See PutGroupConfiguration for more information about the
operation and its arguments.
Constructs a fluent builder for the SearchResources operation.
See SearchResources for more information about the
operation and its arguments.
Constructs a fluent builder for the Tag operation.
See Tag for more information about the
operation and its arguments.
Constructs a fluent builder for the UngroupResources operation.
See UngroupResources for more information about the
operation and its arguments.
Constructs a fluent builder for the Untag operation.
See Untag for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateGroup operation.
See UpdateGroup for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateGroupQuery operation.
See UpdateGroupQuery for more information about the
operation and its arguments.
Creates a client with the given service config and connector override.