Enum aws_sdk_resourcegroups::error::GroupResourcesErrorKind[][src]

#[non_exhaustive]
pub enum GroupResourcesErrorKind {
    BadRequestException(BadRequestException),
    ForbiddenException(ForbiddenException),
    InternalServerErrorException(InternalServerErrorException),
    MethodNotAllowedException(MethodNotAllowedException),
    NotFoundException(NotFoundException),
    TooManyRequestsException(TooManyRequestsException),
    Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the GroupResources operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BadRequestException(BadRequestException)

The request includes one or more parameters that violate validation rules.

Tuple Fields of BadRequestException

0: BadRequestException
ForbiddenException(ForbiddenException)

The caller isn't authorized to make the request. Check permissions.

Tuple Fields of ForbiddenException

0: ForbiddenException
InternalServerErrorException(InternalServerErrorException)

An internal error occurred while processing the request. Try again later.

Tuple Fields of InternalServerErrorException

0: InternalServerErrorException
MethodNotAllowedException(MethodNotAllowedException)

The request uses an HTTP method that isn't allowed for the specified resource.

Tuple Fields of MethodNotAllowedException

0: MethodNotAllowedException
NotFoundException(NotFoundException)

One or more of the specified resources don't exist.

Tuple Fields of NotFoundException

0: NotFoundException
TooManyRequestsException(TooManyRequestsException)

You've exceeded throttling limits by making too many requests in a period of time.

Tuple Fields of TooManyRequestsException

0: TooManyRequestsException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unexpected error, eg. invalid JSON returned by the service or an unknown error code

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>