Struct aws_sdk_resourcegroups::input::group_resources_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GroupResourcesInput
Implementations
The name or the ARN of the resource group to add resources to.
The name or the ARN of the resource group to add resources to.
Appends an item to resource_arns.
To override the contents of this collection use set_resource_arns.
The list of ARNs for resources to be added to the group.
The list of ARNs for resources to be added to the group.
Consumes the builder and constructs a GroupResourcesInput