Struct aws_sdk_resourcegroups::input::list_groups_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for ListGroupsInput
Implementations
Appends an item to filters.
To override the contents of this collection use set_filters.
Filters, formatted as GroupFilter objects, that you want to apply to
a ListGroups operation.
-
resource-type- Filter the results to include only those of the specified resource types. Specify up to five resource types in the formatAWS::ServiceCode::ResourceType. For example,AWS::EC2::Instance, orAWS::S3::Bucket. -
configuration-type- Filter the results to include only those groups that have the specified configuration types attached. The current supported values are:-
AWS:EC2::CapacityReservationPool -
AWS:EC2::HostManagement
-
Filters, formatted as GroupFilter objects, that you want to apply to
a ListGroups operation.
-
resource-type- Filter the results to include only those of the specified resource types. Specify up to five resource types in the formatAWS::ServiceCode::ResourceType. For example,AWS::EC2::Instance, orAWS::S3::Bucket. -
configuration-type- Filter the results to include only those groups that have the specified configuration types attached. The current supported values are:-
AWS:EC2::CapacityReservationPool -
AWS:EC2::HostManagement
-
The total number of results that you want included on each page of the
response. If you do not include this parameter, it defaults to a value that is specific to the
operation. If additional items exist beyond the maximum you specify, the NextToken
response element is present and has a value (is not null). Include that value as the
NextToken request parameter in the next call to the operation to get the next part
of the results. Note that the service might return fewer results than the maximum even when there
are more results available. You should check NextToken after every operation to
ensure that you receive all of the results.
The total number of results that you want included on each page of the
response. If you do not include this parameter, it defaults to a value that is specific to the
operation. If additional items exist beyond the maximum you specify, the NextToken
response element is present and has a value (is not null). Include that value as the
NextToken request parameter in the next call to the operation to get the next part
of the results. Note that the service might return fewer results than the maximum even when there
are more results available. You should check NextToken after every operation to
ensure that you receive all of the results.
The parameter for receiving additional results if you receive a
NextToken response in a previous request. A NextToken response
indicates that more output is available. Set this parameter to the value provided by a previous
call's NextToken response to indicate where the output should continue from.
The parameter for receiving additional results if you receive a
NextToken response in a previous request. A NextToken response
indicates that more output is available. Set this parameter to the value provided by a previous
call's NextToken response to indicate where the output should continue from.
Consumes the builder and constructs a ListGroupsInput