Struct aws_sdk_resourcegroups::input::TagInput [−][src]
#[non_exhaustive]pub struct TagInput {
pub arn: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.arn: Option<String>The ARN of the resource group to which to add tags.
The tags to add to the specified resource group. A tag is a string-to-string map of key-value pairs.
Implementations
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<Tag, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<Tag, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<Tag>