Struct aws_sdk_resourcegroups::input::UpdateGroupInput [−][src]
#[non_exhaustive]pub struct UpdateGroupInput {
pub group_name: Option<String>,
pub group: Option<String>,
pub description: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group_name: Option<String>Don't use this parameter. Use Group instead.
group: Option<String>The name or the ARN of the resource group to modify.
description: Option<String>The new description that you want to update the resource group with. Descriptions can contain letters, numbers, hyphens, underscores, periods, and spaces.
Implementations
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateGroup, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateGroup, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<UpdateGroup>
Creates a new builder-style object to manufacture UpdateGroupInput