Struct aws_sdk_resourcegroups::input::update_group_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for UpdateGroupInput
Implementations
Don't use this parameter. Use Group instead.
Don't use this parameter. Use Group instead.
The name or the ARN of the resource group to modify.
The name or the ARN of the resource group to modify.
The new description that you want to update the resource group with. Descriptions can contain letters, numbers, hyphens, underscores, periods, and spaces.
The new description that you want to update the resource group with. Descriptions can contain letters, numbers, hyphens, underscores, periods, and spaces.
Consumes the builder and constructs a UpdateGroupInput