Struct aws_sdk_resourcegroups::input::update_group_query_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for UpdateGroupQueryInput
Implementations
Don't use this parameter. Use Group instead.
Don't use this parameter. Use Group instead.
The name or the ARN of the resource group to query.
The name or the ARN of the resource group to query.
The resource query to determine which AWS resources are members of this resource group.
A resource group can contain either a Configuration or a
ResourceQuery, but not both.
The resource query to determine which AWS resources are members of this resource group.
A resource group can contain either a Configuration or a
ResourceQuery, but not both.
Consumes the builder and constructs a UpdateGroupQueryInput