Struct aws_sdk_resourcegroups::model::failed_resource::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for FailedResource
Implementations
The ARN of the resource that failed to be added or removed.
The ARN of the resource that failed to be added or removed.
The error message text associated with the failure.
The error message text associated with the failure.
The error code associated with the failure.
The error code associated with the failure.
Consumes the builder and constructs a FailedResource