Struct aws_sdk_resourcegroups::model::group_query::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GroupQuery
Implementations
The name of the resource group that is associated with the specified resource query.
The name of the resource group that is associated with the specified resource query.
The resource query that determines which AWS resources are members of the associated resource group.
The resource query that determines which AWS resources are members of the associated resource group.
Consumes the builder and constructs a GroupQuery