Struct aws_sdk_resourcegroups::model::ListGroupResourcesItem [−][src]
#[non_exhaustive]pub struct ListGroupResourcesItem {
pub identifier: Option<ResourceIdentifier>,
pub status: Option<ResourceStatus>,
}Expand description
A structure returned by the ListGroupResources operation that contains identity and group membership status information for one of the resources in the group.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identifier: Option<ResourceIdentifier>A structure that contains the ARN of a resource and its resource type.
status: Option<ResourceStatus>A structure that contains the status of this resource's membership in the group.
This field is present in the response only if the group is of type
AWS::EC2::HostManagement.
Implementations
A structure that contains the ARN of a resource and its resource type.
A structure that contains the status of this resource's membership in the group.
This field is present in the response only if the group is of type
AWS::EC2::HostManagement.
Creates a new builder-style object to manufacture ListGroupResourcesItem