Struct aws_sdk_resourcegroups::model::PendingResource [−][src]
A structure that identifies a resource that is currently pending addition to the group as a member. Adding a resource to a resource group happens asynchronously as a background task and this one isn't completed yet.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_arn: Option<String>The Amazon resource name (ARN) of the resource that's in a pending state.
Implementations
Creates a new builder-style object to manufacture PendingResource