Struct aws_sdk_resourcegroups::model::ResourceStatus [−][src]
#[non_exhaustive]pub struct ResourceStatus {
pub name: Option<ResourceStatusValue>,
}Expand description
A structure that identifies the current group membership status for a resource. Adding
a resource to a resource group is performed asynchronously as a background task. A
PENDING status indicates, for this resource, that the process isn't
completed yet.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<ResourceStatusValue>The current status.
Implementations
Creates a new builder-style object to manufacture ResourceStatus