pub struct CreateGroupFluentBuilder { /* private fields */ }
Fluent builder constructing a request to CreateGroup.

Creates a resource group with the specified name and description. You can optionally include either a resource query or a service configuration. For more information about constructing a resource query, see Build queries and groups in Resource Groups in the Resource Groups User Guide. For more information about service-linked groups and service configurations, see Service configurations for Resource Groups.

Minimum permissions

To run this command, you must have the following permissions:

  • resource-groups:CreateGroup

Implementations

source

impl CreateGroupFluentBuilder

source

pub fn as_input(&self) -> &CreateGroupInputBuilder

Access the CreateGroup as a reference.

source

pub async fn send( self ) -> Result<CreateGroupOutput, SdkError<CreateGroupError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

source

pub async fn customize( self ) -> Result<CustomizableOperation<CreateGroupOutput, CreateGroupError, Self>, SdkError<CreateGroupError>>

Consumes this builder, creating a customizable operation that can be modified before being sent.

source

pub fn name(self, input: impl Into<String>) -> Self

The name of the group, which is the identifier of the group in other operations. You can't change the name of a resource group after you create it. A resource group name can consist of letters, numbers, hyphens, periods, and underscores. The name cannot start with AWS or aws; these are reserved. A resource group name must be unique within each Amazon Web Services Region in your Amazon Web Services account.

source

pub fn set_name(self, input: Option<String>) -> Self

The name of the group, which is the identifier of the group in other operations. You can't change the name of a resource group after you create it. A resource group name can consist of letters, numbers, hyphens, periods, and underscores. The name cannot start with AWS or aws; these are reserved. A resource group name must be unique within each Amazon Web Services Region in your Amazon Web Services account.

source

pub fn get_name(&self) -> &Option<String>

The name of the group, which is the identifier of the group in other operations. You can't change the name of a resource group after you create it. A resource group name can consist of letters, numbers, hyphens, periods, and underscores. The name cannot start with AWS or aws; these are reserved. A resource group name must be unique within each Amazon Web Services Region in your Amazon Web Services account.

source

pub fn description(self, input: impl Into<String>) -> Self

The description of the resource group. Descriptions can consist of letters, numbers, hyphens, underscores, periods, and spaces.

source

pub fn set_description(self, input: Option<String>) -> Self

The description of the resource group. Descriptions can consist of letters, numbers, hyphens, underscores, periods, and spaces.

source

pub fn get_description(&self) -> &Option<String>

The description of the resource group. Descriptions can consist of letters, numbers, hyphens, underscores, periods, and spaces.

source

pub fn resource_query(self, input: ResourceQuery) -> Self

The resource query that determines which Amazon Web Services resources are members of this group. For more information about resource queries, see Create a tag-based group in Resource Groups.

A resource group can contain either a ResourceQuery or a Configuration, but not both.

source

pub fn set_resource_query(self, input: Option<ResourceQuery>) -> Self

The resource query that determines which Amazon Web Services resources are members of this group. For more information about resource queries, see Create a tag-based group in Resource Groups.

A resource group can contain either a ResourceQuery or a Configuration, but not both.

source

pub fn get_resource_query(&self) -> &Option<ResourceQuery>

The resource query that determines which Amazon Web Services resources are members of this group. For more information about resource queries, see Create a tag-based group in Resource Groups.

A resource group can contain either a ResourceQuery or a Configuration, but not both.

source

pub fn tags(self, k: impl Into<String>, v: impl Into<String>) -> Self

Adds a key-value pair to Tags.

To override the contents of this collection use set_tags.

The tags to add to the group. A tag is key-value pair string.

source

pub fn set_tags(self, input: Option<HashMap<String, String>>) -> Self

The tags to add to the group. A tag is key-value pair string.

source

pub fn get_tags(&self) -> &Option<HashMap<String, String>>

The tags to add to the group. A tag is key-value pair string.

source

pub fn configuration(self, input: GroupConfigurationItem) -> Self

Appends an item to Configuration.

To override the contents of this collection use set_configuration.

A configuration associates the resource group with an Amazon Web Services service and specifies how the service can interact with the resources in the group. A configuration is an array of GroupConfigurationItem elements. For details about the syntax of service configurations, see Service configurations for Resource Groups.

A resource group can contain either a Configuration or a ResourceQuery, but not both.

source

pub fn set_configuration( self, input: Option<Vec<GroupConfigurationItem>> ) -> Self

A configuration associates the resource group with an Amazon Web Services service and specifies how the service can interact with the resources in the group. A configuration is an array of GroupConfigurationItem elements. For details about the syntax of service configurations, see Service configurations for Resource Groups.

A resource group can contain either a Configuration or a ResourceQuery, but not both.

source

pub fn get_configuration(&self) -> &Option<Vec<GroupConfigurationItem>>

A configuration associates the resource group with an Amazon Web Services service and specifies how the service can interact with the resources in the group. A configuration is an array of GroupConfigurationItem elements. For details about the syntax of service configurations, see Service configurations for Resource Groups.

A resource group can contain either a Configuration or a ResourceQuery, but not both.