#[non_exhaustive]pub struct CreateGroupInputBuilder { /* private fields */ }Expand description
A builder for CreateGroupInput.
Implementations
sourceimpl CreateGroupInputBuilder
impl CreateGroupInputBuilder
sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the group, which is the identifier of the group in other operations. You can't change the name of a resource group after you create it. A resource group name can consist of letters, numbers, hyphens, periods, and underscores. The name cannot start with AWS or aws; these are reserved. A resource group name must be unique within each Amazon Web Services Region in your Amazon Web Services account.
sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The name of the group, which is the identifier of the group in other operations. You can't change the name of a resource group after you create it. A resource group name can consist of letters, numbers, hyphens, periods, and underscores. The name cannot start with AWS or aws; these are reserved. A resource group name must be unique within each Amazon Web Services Region in your Amazon Web Services account.
sourcepub fn get_name(&self) -> &Option<String>
pub fn get_name(&self) -> &Option<String>
The name of the group, which is the identifier of the group in other operations. You can't change the name of a resource group after you create it. A resource group name can consist of letters, numbers, hyphens, periods, and underscores. The name cannot start with AWS or aws; these are reserved. A resource group name must be unique within each Amazon Web Services Region in your Amazon Web Services account.
sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the resource group. Descriptions can consist of letters, numbers, hyphens, underscores, periods, and spaces.
sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the resource group. Descriptions can consist of letters, numbers, hyphens, underscores, periods, and spaces.
sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the resource group. Descriptions can consist of letters, numbers, hyphens, underscores, periods, and spaces.
sourcepub fn resource_query(self, input: ResourceQuery) -> Self
pub fn resource_query(self, input: ResourceQuery) -> Self
The resource query that determines which Amazon Web Services resources are members of this group. For more information about resource queries, see Create a tag-based group in Resource Groups.
A resource group can contain either a ResourceQuery or a Configuration, but not both.
sourcepub fn set_resource_query(self, input: Option<ResourceQuery>) -> Self
pub fn set_resource_query(self, input: Option<ResourceQuery>) -> Self
The resource query that determines which Amazon Web Services resources are members of this group. For more information about resource queries, see Create a tag-based group in Resource Groups.
A resource group can contain either a ResourceQuery or a Configuration, but not both.
sourcepub fn get_resource_query(&self) -> &Option<ResourceQuery>
pub fn get_resource_query(&self) -> &Option<ResourceQuery>
The resource query that determines which Amazon Web Services resources are members of this group. For more information about resource queries, see Create a tag-based group in Resource Groups.
A resource group can contain either a ResourceQuery or a Configuration, but not both.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tags to add to the group. A tag is key-value pair string.
The tags to add to the group. A tag is key-value pair string.
The tags to add to the group. A tag is key-value pair string.
sourcepub fn configuration(self, input: GroupConfigurationItem) -> Self
pub fn configuration(self, input: GroupConfigurationItem) -> Self
Appends an item to configuration.
To override the contents of this collection use set_configuration.
A configuration associates the resource group with an Amazon Web Services service and specifies how the service can interact with the resources in the group. A configuration is an array of GroupConfigurationItem elements. For details about the syntax of service configurations, see Service configurations for Resource Groups.
A resource group can contain either a Configuration or a ResourceQuery, but not both.
sourcepub fn set_configuration(
self,
input: Option<Vec<GroupConfigurationItem>>
) -> Self
pub fn set_configuration( self, input: Option<Vec<GroupConfigurationItem>> ) -> Self
A configuration associates the resource group with an Amazon Web Services service and specifies how the service can interact with the resources in the group. A configuration is an array of GroupConfigurationItem elements. For details about the syntax of service configurations, see Service configurations for Resource Groups.
A resource group can contain either a Configuration or a ResourceQuery, but not both.
sourcepub fn get_configuration(&self) -> &Option<Vec<GroupConfigurationItem>>
pub fn get_configuration(&self) -> &Option<Vec<GroupConfigurationItem>>
A configuration associates the resource group with an Amazon Web Services service and specifies how the service can interact with the resources in the group. A configuration is an array of GroupConfigurationItem elements. For details about the syntax of service configurations, see Service configurations for Resource Groups.
A resource group can contain either a Configuration or a ResourceQuery, but not both.
sourcepub fn build(self) -> Result<CreateGroupInput, BuildError>
pub fn build(self) -> Result<CreateGroupInput, BuildError>
Consumes the builder and constructs a CreateGroupInput.
sourceimpl CreateGroupInputBuilder
impl CreateGroupInputBuilder
sourcepub async fn send_with(
self,
client: &Client
) -> Result<CreateGroupOutput, SdkError<CreateGroupError, HttpResponse>>
pub async fn send_with( self, client: &Client ) -> Result<CreateGroupOutput, SdkError<CreateGroupError, HttpResponse>>
Sends a request with this input using the given client.