#[non_exhaustive]pub struct CreateGroupOutputBuilder { /* private fields */ }Expand description
A builder for CreateGroupOutput.
Implementations
sourceimpl CreateGroupOutputBuilder
impl CreateGroupOutputBuilder
sourcepub fn resource_query(self, input: ResourceQuery) -> Self
pub fn resource_query(self, input: ResourceQuery) -> Self
The resource query associated with the group. For more information about resource queries, see Create a tag-based group in Resource Groups.
sourcepub fn set_resource_query(self, input: Option<ResourceQuery>) -> Self
pub fn set_resource_query(self, input: Option<ResourceQuery>) -> Self
The resource query associated with the group. For more information about resource queries, see Create a tag-based group in Resource Groups.
sourcepub fn get_resource_query(&self) -> &Option<ResourceQuery>
pub fn get_resource_query(&self) -> &Option<ResourceQuery>
The resource query associated with the group. For more information about resource queries, see Create a tag-based group in Resource Groups.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tags associated with the group.
The tags associated with the group.
The tags associated with the group.
sourcepub fn group_configuration(self, input: GroupConfiguration) -> Self
pub fn group_configuration(self, input: GroupConfiguration) -> Self
The service configuration associated with the resource group. For details about the syntax of a service configuration, see Service configurations for Resource Groups.
sourcepub fn set_group_configuration(self, input: Option<GroupConfiguration>) -> Self
pub fn set_group_configuration(self, input: Option<GroupConfiguration>) -> Self
The service configuration associated with the resource group. For details about the syntax of a service configuration, see Service configurations for Resource Groups.
sourcepub fn get_group_configuration(&self) -> &Option<GroupConfiguration>
pub fn get_group_configuration(&self) -> &Option<GroupConfiguration>
The service configuration associated with the resource group. For details about the syntax of a service configuration, see Service configurations for Resource Groups.
sourcepub fn build(self) -> CreateGroupOutput
pub fn build(self) -> CreateGroupOutput
Consumes the builder and constructs a CreateGroupOutput.