#[non_exhaustive]
pub struct CreateGroupInput { pub name: Option<String>, pub description: Option<String>, pub resource_query: Option<ResourceQuery>, pub tags: Option<HashMap<String, String>>, pub configuration: Option<Vec<GroupConfigurationItem>>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: Option<String>

The name of the group, which is the identifier of the group in other operations. You can't change the name of a resource group after you create it. A resource group name can consist of letters, numbers, hyphens, periods, and underscores. The name cannot start with AWS or aws; these are reserved. A resource group name must be unique within each Amazon Web Services Region in your Amazon Web Services account.

description: Option<String>

The description of the resource group. Descriptions can consist of letters, numbers, hyphens, underscores, periods, and spaces.

resource_query: Option<ResourceQuery>

The resource query that determines which Amazon Web Services resources are members of this group. For more information about resource queries, see Create a tag-based group in Resource Groups.

A resource group can contain either a ResourceQuery or a Configuration, but not both.

tags: Option<HashMap<String, String>>

The tags to add to the group. A tag is key-value pair string.

configuration: Option<Vec<GroupConfigurationItem>>

A configuration associates the resource group with an Amazon Web Services service and specifies how the service can interact with the resources in the group. A configuration is an array of GroupConfigurationItem elements. For details about the syntax of service configurations, see Service configurations for Resource Groups.

A resource group can contain either a Configuration or a ResourceQuery, but not both.

Implementations

source

impl CreateGroupInput

source

pub fn name(&self) -> Option<&str>

The name of the group, which is the identifier of the group in other operations. You can't change the name of a resource group after you create it. A resource group name can consist of letters, numbers, hyphens, periods, and underscores. The name cannot start with AWS or aws; these are reserved. A resource group name must be unique within each Amazon Web Services Region in your Amazon Web Services account.

source

pub fn description(&self) -> Option<&str>

The description of the resource group. Descriptions can consist of letters, numbers, hyphens, underscores, periods, and spaces.

source

pub fn resource_query(&self) -> Option<&ResourceQuery>

The resource query that determines which Amazon Web Services resources are members of this group. For more information about resource queries, see Create a tag-based group in Resource Groups.

A resource group can contain either a ResourceQuery or a Configuration, but not both.

source

pub fn tags(&self) -> Option<&HashMap<String, String>>

The tags to add to the group. A tag is key-value pair string.

source

pub fn configuration(&self) -> Option<&[GroupConfigurationItem]>

A configuration associates the resource group with an Amazon Web Services service and specifies how the service can interact with the resources in the group. A configuration is an array of GroupConfigurationItem elements. For details about the syntax of service configurations, see Service configurations for Resource Groups.

A resource group can contain either a Configuration or a ResourceQuery, but not both.

source

impl CreateGroupInput

source

pub fn builder() -> CreateGroupInputBuilder

Creates a new builder-style object to manufacture CreateGroupInput.