#[non_exhaustive]pub struct CreateGroupOutput {
pub group: Option<Group>,
pub resource_query: Option<ResourceQuery>,
pub tags: Option<HashMap<String, String>>,
pub group_configuration: Option<GroupConfiguration>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group: Option<Group>The description of the resource group.
resource_query: Option<ResourceQuery>The resource query associated with the group. For more information about resource queries, see Create a tag-based group in Resource Groups.
The tags associated with the group.
group_configuration: Option<GroupConfiguration>The service configuration associated with the resource group. For details about the syntax of a service configuration, see Service configurations for Resource Groups.
Implementations
sourceimpl CreateGroupOutput
impl CreateGroupOutput
sourcepub fn resource_query(&self) -> Option<&ResourceQuery>
pub fn resource_query(&self) -> Option<&ResourceQuery>
The resource query associated with the group. For more information about resource queries, see Create a tag-based group in Resource Groups.
The tags associated with the group.
sourcepub fn group_configuration(&self) -> Option<&GroupConfiguration>
pub fn group_configuration(&self) -> Option<&GroupConfiguration>
The service configuration associated with the resource group. For details about the syntax of a service configuration, see Service configurations for Resource Groups.
sourceimpl CreateGroupOutput
impl CreateGroupOutput
sourcepub fn builder() -> CreateGroupOutputBuilder
pub fn builder() -> CreateGroupOutputBuilder
Creates a new builder-style object to manufacture CreateGroupOutput.