Struct aws_sdk_resourcegroups::operation::get_group_configuration::GetGroupConfigurationOutput
source · #[non_exhaustive]pub struct GetGroupConfigurationOutput {
pub group_configuration: Option<GroupConfiguration>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group_configuration: Option<GroupConfiguration>A structure that describes the service configuration attached with the specified group. For details about the service configuration syntax, see Service configurations for Resource Groups.
Implementations
sourceimpl GetGroupConfigurationOutput
impl GetGroupConfigurationOutput
sourcepub fn group_configuration(&self) -> Option<&GroupConfiguration>
pub fn group_configuration(&self) -> Option<&GroupConfiguration>
A structure that describes the service configuration attached with the specified group. For details about the service configuration syntax, see Service configurations for Resource Groups.
sourceimpl GetGroupConfigurationOutput
impl GetGroupConfigurationOutput
sourcepub fn builder() -> GetGroupConfigurationOutputBuilder
pub fn builder() -> GetGroupConfigurationOutputBuilder
Creates a new builder-style object to manufacture GetGroupConfigurationOutput.