Struct aws_sdk_resourcegroups::operation::get_group_query::builders::GetGroupQueryOutputBuilder
source · #[non_exhaustive]pub struct GetGroupQueryOutputBuilder { /* private fields */ }Expand description
A builder for GetGroupQueryOutput.
Implementations
sourceimpl GetGroupQueryOutputBuilder
impl GetGroupQueryOutputBuilder
sourcepub fn group_query(self, input: GroupQuery) -> Self
pub fn group_query(self, input: GroupQuery) -> Self
The resource query associated with the specified group. For more information about resource queries, see Create a tag-based group in Resource Groups.
sourcepub fn set_group_query(self, input: Option<GroupQuery>) -> Self
pub fn set_group_query(self, input: Option<GroupQuery>) -> Self
The resource query associated with the specified group. For more information about resource queries, see Create a tag-based group in Resource Groups.
sourcepub fn get_group_query(&self) -> &Option<GroupQuery>
pub fn get_group_query(&self) -> &Option<GroupQuery>
The resource query associated with the specified group. For more information about resource queries, see Create a tag-based group in Resource Groups.
sourcepub fn build(self) -> GetGroupQueryOutput
pub fn build(self) -> GetGroupQueryOutput
Consumes the builder and constructs a GetGroupQueryOutput.