#[non_exhaustive]pub struct GetGroupQueryOutput {
pub group_query: Option<GroupQuery>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group_query: Option<GroupQuery>The resource query associated with the specified group. For more information about resource queries, see Create a tag-based group in Resource Groups.
Implementations
sourceimpl GetGroupQueryOutput
impl GetGroupQueryOutput
sourcepub fn group_query(&self) -> Option<&GroupQuery>
pub fn group_query(&self) -> Option<&GroupQuery>
The resource query associated with the specified group. For more information about resource queries, see Create a tag-based group in Resource Groups.
sourceimpl GetGroupQueryOutput
impl GetGroupQueryOutput
sourcepub fn builder() -> GetGroupQueryOutputBuilder
pub fn builder() -> GetGroupQueryOutputBuilder
Creates a new builder-style object to manufacture GetGroupQueryOutput.