#[non_exhaustive]pub struct ListGroupResourcesInput {
pub group_name: Option<String>,
pub group: Option<String>,
pub filters: Option<Vec<ResourceFilter>>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group_name: Option<String>This field is deprecated, use Group instead.
Deprecated - don't use this parameter. Use the Group request field instead.
group: Option<String>The name or the Amazon resource name (ARN) of the resource group.
filters: Option<Vec<ResourceFilter>>Filters, formatted as ResourceFilter objects, that you want to apply to a ListGroupResources operation. Filters the results to include only those of the specified resource types.
-
resource-type- Filter resources by their type. Specify up to five resource types in the formatAWS::ServiceCode::ResourceType. For example,AWS::EC2::Instance, orAWS::S3::Bucket.
When you specify a resource-type filter for ListGroupResources, Resource Groups validates your filter resource types against the types that are defined in the query associated with the group. For example, if a group contains only S3 buckets because its query specifies only that resource type, but your resource-type filter includes EC2 instances, AWS Resource Groups does not filter for EC2 instances. In this case, a ListGroupResources request returns a BadRequestException error with a message similar to the following:
The resource types specified as filters in the request are not valid.
The error includes a list of resource types that failed the validation because they are not part of the query associated with the group. This validation doesn't occur when the group query specifies AWS::AllSupported, because a group based on such a query can contain any of the allowed resource types for the query type (tag-based or Amazon CloudFront stack-based queries).
max_results: Option<i32>The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.
next_token: Option<String>The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value provided by a previous call's NextToken response to indicate where the output should continue from.
Implementations
Sourceimpl ListGroupResourcesInput
impl ListGroupResourcesInput
Sourcepub fn group_name(&self) -> Option<&str>
👎Deprecated: This field is deprecated, use Group instead.
pub fn group_name(&self) -> Option<&str>
This field is deprecated, use Group instead.
Deprecated - don't use this parameter. Use the Group request field instead.
Sourcepub fn group(&self) -> Option<&str>
pub fn group(&self) -> Option<&str>
The name or the Amazon resource name (ARN) of the resource group.
Sourcepub fn filters(&self) -> &[ResourceFilter]
pub fn filters(&self) -> &[ResourceFilter]
Filters, formatted as ResourceFilter objects, that you want to apply to a ListGroupResources operation. Filters the results to include only those of the specified resource types.
-
resource-type- Filter resources by their type. Specify up to five resource types in the formatAWS::ServiceCode::ResourceType. For example,AWS::EC2::Instance, orAWS::S3::Bucket.
When you specify a resource-type filter for ListGroupResources, Resource Groups validates your filter resource types against the types that are defined in the query associated with the group. For example, if a group contains only S3 buckets because its query specifies only that resource type, but your resource-type filter includes EC2 instances, AWS Resource Groups does not filter for EC2 instances. In this case, a ListGroupResources request returns a BadRequestException error with a message similar to the following:
The resource types specified as filters in the request are not valid.
The error includes a list of resource types that failed the validation because they are not part of the query associated with the group. This validation doesn't occur when the group query specifies AWS::AllSupported, because a group based on such a query can contain any of the allowed resource types for the query type (tag-based or Amazon CloudFront stack-based queries).
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .filters.is_none().
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value provided by a previous call's NextToken response to indicate where the output should continue from.
Sourceimpl ListGroupResourcesInput
impl ListGroupResourcesInput
Sourcepub fn builder() -> ListGroupResourcesInputBuilder
pub fn builder() -> ListGroupResourcesInputBuilder
Creates a new builder-style object to manufacture ListGroupResourcesInput.