#[non_exhaustive]pub struct ListGroupsInputBuilder { /* private fields */ }Expand description
A builder for ListGroupsInput.
Implementations
Sourceimpl ListGroupsInputBuilder
impl ListGroupsInputBuilder
Sourcepub fn filters(self, input: GroupFilter) -> Self
pub fn filters(self, input: GroupFilter) -> Self
Appends an item to filters.
To override the contents of this collection use set_filters.
Filters, formatted as GroupFilter objects, that you want to apply to a ListGroups operation.
-
resource-type- Filter the results to include only those resource groups that have the specified resource type in theirResourceTypeFilter. For example,AWS::EC2::Instancewould return any resource group with aResourceTypeFilterthat includesAWS::EC2::Instance. -
configuration-type- Filter the results to include only those groups that have the specified configuration types attached. The current supported values are:-
AWS::ResourceGroups::ApplicationGroup -
AWS::AppRegistry::Application -
AWS::AppRegistry::ApplicationResourceGroup -
AWS::CloudFormation::Stack -
AWS::EC2::CapacityReservationPool -
AWS::EC2::HostManagement -
AWS::NetworkFirewall::RuleGroup
-
Sourcepub fn set_filters(self, input: Option<Vec<GroupFilter>>) -> Self
pub fn set_filters(self, input: Option<Vec<GroupFilter>>) -> Self
Filters, formatted as GroupFilter objects, that you want to apply to a ListGroups operation.
-
resource-type- Filter the results to include only those resource groups that have the specified resource type in theirResourceTypeFilter. For example,AWS::EC2::Instancewould return any resource group with aResourceTypeFilterthat includesAWS::EC2::Instance. -
configuration-type- Filter the results to include only those groups that have the specified configuration types attached. The current supported values are:-
AWS::ResourceGroups::ApplicationGroup -
AWS::AppRegistry::Application -
AWS::AppRegistry::ApplicationResourceGroup -
AWS::CloudFormation::Stack -
AWS::EC2::CapacityReservationPool -
AWS::EC2::HostManagement -
AWS::NetworkFirewall::RuleGroup
-
Sourcepub fn get_filters(&self) -> &Option<Vec<GroupFilter>>
pub fn get_filters(&self) -> &Option<Vec<GroupFilter>>
Filters, formatted as GroupFilter objects, that you want to apply to a ListGroups operation.
-
resource-type- Filter the results to include only those resource groups that have the specified resource type in theirResourceTypeFilter. For example,AWS::EC2::Instancewould return any resource group with aResourceTypeFilterthat includesAWS::EC2::Instance. -
configuration-type- Filter the results to include only those groups that have the specified configuration types attached. The current supported values are:-
AWS::ResourceGroups::ApplicationGroup -
AWS::AppRegistry::Application -
AWS::AppRegistry::ApplicationResourceGroup -
AWS::CloudFormation::Stack -
AWS::EC2::CapacityReservationPool -
AWS::EC2::HostManagement -
AWS::NetworkFirewall::RuleGroup
-
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value provided by a previous call's NextToken response to indicate where the output should continue from.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value provided by a previous call's NextToken response to indicate where the output should continue from.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value provided by a previous call's NextToken response to indicate where the output should continue from.
Sourcepub fn build(self) -> Result<ListGroupsInput, BuildError>
pub fn build(self) -> Result<ListGroupsInput, BuildError>
Consumes the builder and constructs a ListGroupsInput.
Sourceimpl ListGroupsInputBuilder
impl ListGroupsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListGroupsOutput, SdkError<ListGroupsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListGroupsOutput, SdkError<ListGroupsError, HttpResponse>>
Sends a request with this input using the given client.