#[non_exhaustive]pub enum ListGroupsError {
BadRequestException(BadRequestException),
ForbiddenException(ForbiddenException),
InternalServerErrorException(InternalServerErrorException),
MethodNotAllowedException(MethodNotAllowedException),
TooManyRequestsException(TooManyRequestsException),
Unhandled(Unhandled),
}Expand description
Error type for the ListGroupsError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BadRequestException(BadRequestException)
The request includes one or more parameters that violate validation rules.
ForbiddenException(ForbiddenException)
The caller isn't authorized to make the request. Check permissions.
InternalServerErrorException(InternalServerErrorException)
An internal error occurred while processing the request. Try again later.
MethodNotAllowedException(MethodNotAllowedException)
The request uses an HTTP method that isn't allowed for the specified resource.
TooManyRequestsException(TooManyRequestsException)
You've exceeded throttling limits by making too many requests in a period of time.
Unhandled(Unhandled)
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
sourceimpl ListGroupsError
impl ListGroupsError
sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the ListGroupsError::Unhandled variant from any error type.
sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the ListGroupsError::Unhandled variant from a ::aws_smithy_types::error::ErrorMetadata.
sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
sourcepub fn is_bad_request_exception(&self) -> bool
pub fn is_bad_request_exception(&self) -> bool
Returns true if the error kind is ListGroupsError::BadRequestException.
sourcepub fn is_forbidden_exception(&self) -> bool
pub fn is_forbidden_exception(&self) -> bool
Returns true if the error kind is ListGroupsError::ForbiddenException.
sourcepub fn is_internal_server_error_exception(&self) -> bool
pub fn is_internal_server_error_exception(&self) -> bool
Returns true if the error kind is ListGroupsError::InternalServerErrorException.
sourcepub fn is_method_not_allowed_exception(&self) -> bool
pub fn is_method_not_allowed_exception(&self) -> bool
Returns true if the error kind is ListGroupsError::MethodNotAllowedException.
sourcepub fn is_too_many_requests_exception(&self) -> bool
pub fn is_too_many_requests_exception(&self) -> bool
Returns true if the error kind is ListGroupsError::TooManyRequestsException.