#[non_exhaustive]pub struct ListGroupsInput {
pub filters: Option<Vec<GroupFilter>>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.filters: Option<Vec<GroupFilter>>Filters, formatted as GroupFilter objects, that you want to apply to a ListGroups operation.
-
resource-type- Filter the results to include only those of the specified resource types. Specify up to five resource types in the formatAWS::ServiceCode::ResourceType. For example,AWS::EC2::Instance, orAWS::S3::Bucket. -
configuration-type- Filter the results to include only those groups that have the specified configuration types attached. The current supported values are:-
AWS::EC2::CapacityReservationPool -
AWS::EC2::HostManagement
-
max_results: Option<i32>The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.
next_token: Option<String>The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value provided by a previous call's NextToken response to indicate where the output should continue from.
Implementations
sourceimpl ListGroupsInput
impl ListGroupsInput
sourcepub fn filters(&self) -> &[GroupFilter]
pub fn filters(&self) -> &[GroupFilter]
Filters, formatted as GroupFilter objects, that you want to apply to a ListGroups operation.
-
resource-type- Filter the results to include only those of the specified resource types. Specify up to five resource types in the formatAWS::ServiceCode::ResourceType. For example,AWS::EC2::Instance, orAWS::S3::Bucket. -
configuration-type- Filter the results to include only those groups that have the specified configuration types attached. The current supported values are:-
AWS::EC2::CapacityReservationPool -
AWS::EC2::HostManagement
-
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .filters.is_none().
sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value provided by a previous call's NextToken response to indicate where the output should continue from.
sourceimpl ListGroupsInput
impl ListGroupsInput
sourcepub fn builder() -> ListGroupsInputBuilder
pub fn builder() -> ListGroupsInputBuilder
Creates a new builder-style object to manufacture ListGroupsInput.