#[non_exhaustive]pub struct ListGroupsOutput {
pub group_identifiers: Option<Vec<GroupIdentifier>>,
pub groups: Option<Vec<Group>>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group_identifiers: Option<Vec<GroupIdentifier>>A list of GroupIdentifier objects. Each identifier is an object that contains both the Name and the GroupArn.
groups: Option<Vec<Group>> Deprecated - don't use this field. Use the GroupIdentifiers response field instead.
next_token: Option<String>If present, indicates that more output is available than is included in the current response. Use this value in the NextToken request parameter in a subsequent call to the operation to get the next part of the output. You should repeat this until the NextToken response element comes back as null.
Implementations
sourceimpl ListGroupsOutput
impl ListGroupsOutput
sourcepub fn group_identifiers(&self) -> &[GroupIdentifier]
pub fn group_identifiers(&self) -> &[GroupIdentifier]
A list of GroupIdentifier objects. Each identifier is an object that contains both the Name and the GroupArn.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .group_identifiers.is_none().
sourcepub fn groups(&self) -> &[Group]
👎Deprecated: This field is deprecated, use GroupIdentifiers instead.
pub fn groups(&self) -> &[Group]
Deprecated - don't use this field. Use the GroupIdentifiers response field instead.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .groups.is_none().
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
If present, indicates that more output is available than is included in the current response. Use this value in the NextToken request parameter in a subsequent call to the operation to get the next part of the output. You should repeat this until the NextToken response element comes back as null.
sourceimpl ListGroupsOutput
impl ListGroupsOutput
sourcepub fn builder() -> ListGroupsOutputBuilder
pub fn builder() -> ListGroupsOutputBuilder
Creates a new builder-style object to manufacture ListGroupsOutput.