Struct aws_sdk_resourcegroups::operation::put_group_configuration::PutGroupConfigurationInput
source · #[non_exhaustive]pub struct PutGroupConfigurationInput {
pub group: Option<String>,
pub configuration: Option<Vec<GroupConfigurationItem>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group: Option<String>The name or ARN of the resource group with the configuration that you want to update.
configuration: Option<Vec<GroupConfigurationItem>>The new configuration to associate with the specified group. A configuration associates the resource group with an Amazon Web Services service and specifies how the service can interact with the resources in the group. A configuration is an array of GroupConfigurationItem elements.
For information about the syntax of a service configuration, see Service configurations for Resource Groups.
A resource group can contain either a Configuration or a ResourceQuery, but not both.
Implementations
sourceimpl PutGroupConfigurationInput
impl PutGroupConfigurationInput
sourcepub fn group(&self) -> Option<&str>
pub fn group(&self) -> Option<&str>
The name or ARN of the resource group with the configuration that you want to update.
sourcepub fn configuration(&self) -> &[GroupConfigurationItem]
pub fn configuration(&self) -> &[GroupConfigurationItem]
The new configuration to associate with the specified group. A configuration associates the resource group with an Amazon Web Services service and specifies how the service can interact with the resources in the group. A configuration is an array of GroupConfigurationItem elements.
For information about the syntax of a service configuration, see Service configurations for Resource Groups.
A resource group can contain either a Configuration or a ResourceQuery, but not both.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .configuration.is_none().
sourceimpl PutGroupConfigurationInput
impl PutGroupConfigurationInput
sourcepub fn builder() -> PutGroupConfigurationInputBuilder
pub fn builder() -> PutGroupConfigurationInputBuilder
Creates a new builder-style object to manufacture PutGroupConfigurationInput.