#[non_exhaustive]pub struct SearchResourcesInput {
pub resource_query: Option<ResourceQuery>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_query: Option<ResourceQuery>The search query, using the same formats that are supported for resource group definition. For more information, see CreateGroup.
max_results: Option<i32>The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.
next_token: Option<String>The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value provided by a previous call's NextToken response to indicate where the output should continue from.
Implementations
Sourceimpl SearchResourcesInput
impl SearchResourcesInput
Sourcepub fn resource_query(&self) -> Option<&ResourceQuery>
pub fn resource_query(&self) -> Option<&ResourceQuery>
The search query, using the same formats that are supported for resource group definition. For more information, see CreateGroup.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value provided by a previous call's NextToken response to indicate where the output should continue from.
Sourceimpl SearchResourcesInput
impl SearchResourcesInput
Sourcepub fn builder() -> SearchResourcesInputBuilder
pub fn builder() -> SearchResourcesInputBuilder
Creates a new builder-style object to manufacture SearchResourcesInput.