#[non_exhaustive]pub enum UpdateGroupError {
BadRequestException(BadRequestException),
ForbiddenException(ForbiddenException),
InternalServerErrorException(InternalServerErrorException),
MethodNotAllowedException(MethodNotAllowedException),
NotFoundException(NotFoundException),
TooManyRequestsException(TooManyRequestsException),
Unhandled(Unhandled),
}Expand description
Error type for the UpdateGroupError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BadRequestException(BadRequestException)
The request includes one or more parameters that violate validation rules.
ForbiddenException(ForbiddenException)
The caller isn't authorized to make the request. Check permissions.
InternalServerErrorException(InternalServerErrorException)
An internal error occurred while processing the request. Try again later.
MethodNotAllowedException(MethodNotAllowedException)
The request uses an HTTP method that isn't allowed for the specified resource.
NotFoundException(NotFoundException)
One or more of the specified resources don't exist.
TooManyRequestsException(TooManyRequestsException)
You've exceeded throttling limits by making too many requests in a period of time.
Unhandled(Unhandled)
Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
sourceimpl UpdateGroupError
impl UpdateGroupError
sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the UpdateGroupError::Unhandled variant from any error type.
sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the UpdateGroupError::Unhandled variant from an ErrorMetadata.
sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
sourcepub fn is_bad_request_exception(&self) -> bool
pub fn is_bad_request_exception(&self) -> bool
Returns true if the error kind is UpdateGroupError::BadRequestException.
sourcepub fn is_forbidden_exception(&self) -> bool
pub fn is_forbidden_exception(&self) -> bool
Returns true if the error kind is UpdateGroupError::ForbiddenException.
sourcepub fn is_internal_server_error_exception(&self) -> bool
pub fn is_internal_server_error_exception(&self) -> bool
Returns true if the error kind is UpdateGroupError::InternalServerErrorException.
sourcepub fn is_method_not_allowed_exception(&self) -> bool
pub fn is_method_not_allowed_exception(&self) -> bool
Returns true if the error kind is UpdateGroupError::MethodNotAllowedException.
sourcepub fn is_not_found_exception(&self) -> bool
pub fn is_not_found_exception(&self) -> bool
Returns true if the error kind is UpdateGroupError::NotFoundException.
sourcepub fn is_too_many_requests_exception(&self) -> bool
pub fn is_too_many_requests_exception(&self) -> bool
Returns true if the error kind is UpdateGroupError::TooManyRequestsException.