Struct aws_sdk_resourcegroups::operation::update_group_query::builders::UpdateGroupQueryFluentBuilder
source · pub struct UpdateGroupQueryFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateGroupQuery.
Updates the resource query of a group. For more information about resource queries, see Create a tag-based group in Resource Groups.
Minimum permissions
To run this command, you must have the following permissions:
-
resource-groups:UpdateGroupQuery
Implementations
sourceimpl UpdateGroupQueryFluentBuilder
impl UpdateGroupQueryFluentBuilder
sourcepub fn as_input(&self) -> &UpdateGroupQueryInputBuilder
pub fn as_input(&self) -> &UpdateGroupQueryInputBuilder
Access the UpdateGroupQuery as a reference.
sourcepub async fn send(
self
) -> Result<UpdateGroupQueryOutput, SdkError<UpdateGroupQueryError, HttpResponse>>
pub async fn send( self ) -> Result<UpdateGroupQueryOutput, SdkError<UpdateGroupQueryError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn customize(
self
) -> CustomizableOperation<UpdateGroupQueryOutput, UpdateGroupQueryError, Self>
pub fn customize( self ) -> CustomizableOperation<UpdateGroupQueryOutput, UpdateGroupQueryError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
sourcepub fn group_name(self, input: impl Into<String>) -> Self
👎Deprecated: This field is deprecated, use Group instead.
pub fn group_name(self, input: impl Into<String>) -> Self
Don't use this parameter. Use Group instead.
sourcepub fn set_group_name(self, input: Option<String>) -> Self
👎Deprecated: This field is deprecated, use Group instead.
pub fn set_group_name(self, input: Option<String>) -> Self
Don't use this parameter. Use Group instead.
sourcepub fn get_group_name(&self) -> &Option<String>
👎Deprecated: This field is deprecated, use Group instead.
pub fn get_group_name(&self) -> &Option<String>
Don't use this parameter. Use Group instead.
sourcepub fn group(self, input: impl Into<String>) -> Self
pub fn group(self, input: impl Into<String>) -> Self
The name or the ARN of the resource group to query.
sourcepub fn set_group(self, input: Option<String>) -> Self
pub fn set_group(self, input: Option<String>) -> Self
The name or the ARN of the resource group to query.
sourcepub fn resource_query(self, input: ResourceQuery) -> Self
pub fn resource_query(self, input: ResourceQuery) -> Self
The resource query to determine which Amazon Web Services resources are members of this resource group.
A resource group can contain either a Configuration or a ResourceQuery, but not both.
sourcepub fn set_resource_query(self, input: Option<ResourceQuery>) -> Self
pub fn set_resource_query(self, input: Option<ResourceQuery>) -> Self
The resource query to determine which Amazon Web Services resources are members of this resource group.
A resource group can contain either a Configuration or a ResourceQuery, but not both.
sourcepub fn get_resource_query(&self) -> &Option<ResourceQuery>
pub fn get_resource_query(&self) -> &Option<ResourceQuery>
The resource query to determine which Amazon Web Services resources are members of this resource group.
A resource group can contain either a Configuration or a ResourceQuery, but not both.