Struct aws_sdk_resourcegroups::operation::update_group_query::builders::UpdateGroupQueryInputBuilder
source · #[non_exhaustive]pub struct UpdateGroupQueryInputBuilder { /* private fields */ }Expand description
A builder for UpdateGroupQueryInput.
Implementations
sourceimpl UpdateGroupQueryInputBuilder
impl UpdateGroupQueryInputBuilder
sourcepub fn group_name(self, input: impl Into<String>) -> Self
👎Deprecated: This field is deprecated, use Group instead.
pub fn group_name(self, input: impl Into<String>) -> Self
Don't use this parameter. Use Group instead.
sourcepub fn set_group_name(self, input: Option<String>) -> Self
👎Deprecated: This field is deprecated, use Group instead.
pub fn set_group_name(self, input: Option<String>) -> Self
Don't use this parameter. Use Group instead.
sourcepub fn get_group_name(&self) -> &Option<String>
👎Deprecated: This field is deprecated, use Group instead.
pub fn get_group_name(&self) -> &Option<String>
Don't use this parameter. Use Group instead.
sourcepub fn group(self, input: impl Into<String>) -> Self
pub fn group(self, input: impl Into<String>) -> Self
The name or the ARN of the resource group to query.
sourcepub fn set_group(self, input: Option<String>) -> Self
pub fn set_group(self, input: Option<String>) -> Self
The name or the ARN of the resource group to query.
sourcepub fn resource_query(self, input: ResourceQuery) -> Self
pub fn resource_query(self, input: ResourceQuery) -> Self
The resource query to determine which Amazon Web Services resources are members of this resource group.
A resource group can contain either a Configuration or a ResourceQuery, but not both.
sourcepub fn set_resource_query(self, input: Option<ResourceQuery>) -> Self
pub fn set_resource_query(self, input: Option<ResourceQuery>) -> Self
The resource query to determine which Amazon Web Services resources are members of this resource group.
A resource group can contain either a Configuration or a ResourceQuery, but not both.
sourcepub fn get_resource_query(&self) -> &Option<ResourceQuery>
pub fn get_resource_query(&self) -> &Option<ResourceQuery>
The resource query to determine which Amazon Web Services resources are members of this resource group.
A resource group can contain either a Configuration or a ResourceQuery, but not both.
sourcepub fn build(self) -> Result<UpdateGroupQueryInput, BuildError>
pub fn build(self) -> Result<UpdateGroupQueryInput, BuildError>
Consumes the builder and constructs a UpdateGroupQueryInput.
sourceimpl UpdateGroupQueryInputBuilder
impl UpdateGroupQueryInputBuilder
sourcepub async fn send_with(
self,
client: &Client
) -> Result<UpdateGroupQueryOutput, SdkError<UpdateGroupQueryError, HttpResponse>>
pub async fn send_with( self, client: &Client ) -> Result<UpdateGroupQueryOutput, SdkError<UpdateGroupQueryError, HttpResponse>>
Sends a request with this input using the given client.