Struct aws_sdk_resourcegroups::operation::update_group_query::builders::UpdateGroupQueryOutputBuilder
source · #[non_exhaustive]pub struct UpdateGroupQueryOutputBuilder { /* private fields */ }Expand description
A builder for UpdateGroupQueryOutput.
Implementations
sourceimpl UpdateGroupQueryOutputBuilder
impl UpdateGroupQueryOutputBuilder
sourcepub fn group_query(self, input: GroupQuery) -> Self
pub fn group_query(self, input: GroupQuery) -> Self
The updated resource query associated with the resource group after the update.
sourcepub fn set_group_query(self, input: Option<GroupQuery>) -> Self
pub fn set_group_query(self, input: Option<GroupQuery>) -> Self
The updated resource query associated with the resource group after the update.
sourcepub fn get_group_query(&self) -> &Option<GroupQuery>
pub fn get_group_query(&self) -> &Option<GroupQuery>
The updated resource query associated with the resource group after the update.
sourcepub fn build(self) -> UpdateGroupQueryOutput
pub fn build(self) -> UpdateGroupQueryOutput
Consumes the builder and constructs a UpdateGroupQueryOutput.