#[non_exhaustive]pub struct UpdateGroupQueryOutput {
pub group_query: Option<GroupQuery>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group_query: Option<GroupQuery>The updated resource query associated with the resource group after the update.
Implementations
sourceimpl UpdateGroupQueryOutput
impl UpdateGroupQueryOutput
sourcepub fn group_query(&self) -> Option<&GroupQuery>
pub fn group_query(&self) -> Option<&GroupQuery>
The updated resource query associated with the resource group after the update.
sourceimpl UpdateGroupQueryOutput
impl UpdateGroupQueryOutput
sourcepub fn builder() -> UpdateGroupQueryOutputBuilder
pub fn builder() -> UpdateGroupQueryOutputBuilder
Creates a new builder-style object to manufacture UpdateGroupQueryOutput.