Struct aws_sdk_resourcegroups::output::GroupResourcesOutput [−][src]
#[non_exhaustive]pub struct GroupResourcesOutput {
pub succeeded: Option<Vec<String>>,
pub failed: Option<Vec<FailedResource>>,
pub pending: Option<Vec<PendingResource>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.succeeded: Option<Vec<String>>A list of ARNs of resources that were successfully added to the group by this operation.
failed: Option<Vec<FailedResource>>A list of ARNs of any resources that failed to be added to the group by this operation.
pending: Option<Vec<PendingResource>>A list of ARNs of any resources that are still in the process of being added to the
group by this operation. These pending additions continue asynchronously. You can check
the status of pending additions by using the
ListGroupResources
operation, and checking the Resources array in the response
and the Status field of each object in that array.
Implementations
Creates a new builder-style object to manufacture GroupResourcesOutput