Struct aws_sdk_resourcegroups::output::ListGroupResourcesOutput [−][src]
#[non_exhaustive]pub struct ListGroupResourcesOutput {
pub resources: Option<Vec<ListGroupResourcesItem>>,
pub resource_identifiers: Option<Vec<ResourceIdentifier>>,
pub next_token: Option<String>,
pub query_errors: Option<Vec<QueryError>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resources: Option<Vec<ListGroupResourcesItem>>An array of resources from which you can determine each resource's identity, type, and group membership status.
resource_identifiers: Option<Vec<ResourceIdentifier>>
Deprecated - don't use this parameter. Use the
Resources response field
instead.
next_token: Option<String>If present, indicates that more output is available than is
included in the current response. Use this value in the NextToken request parameter
in a subsequent call to the operation to get the next part of the output. You should repeat this
until the NextToken response element comes back as null.
query_errors: Option<Vec<QueryError>>A list of QueryError objects. Each error is an object that contains
ErrorCode and Message structures. Possible values for
ErrorCode are CLOUDFORMATION_STACK_INACTIVE and
CLOUDFORMATION_STACK_NOT_EXISTING.
Implementations
An array of resources from which you can determine each resource's identity, type, and group membership status.
Deprecated - don't use this parameter. Use the
Resources response field
instead.
If present, indicates that more output is available than is
included in the current response. Use this value in the NextToken request parameter
in a subsequent call to the operation to get the next part of the output. You should repeat this
until the NextToken response element comes back as null.
A list of QueryError objects. Each error is an object that contains
ErrorCode and Message structures. Possible values for
ErrorCode are CLOUDFORMATION_STACK_INACTIVE and
CLOUDFORMATION_STACK_NOT_EXISTING.
Creates a new builder-style object to manufacture ListGroupResourcesOutput