Struct aws_sdk_resourcegroups::output::ListGroupsOutput [−][src]
#[non_exhaustive]pub struct ListGroupsOutput {
pub group_identifiers: Option<Vec<GroupIdentifier>>,
pub groups: Option<Vec<Group>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group_identifiers: Option<Vec<GroupIdentifier>>A list of GroupIdentifier objects. Each identifier is an object that
contains both the Name and the GroupArn.
groups: Option<Vec<Group>>
Deprecated - don't use this field. Use the
GroupIdentifiers response field
instead.
next_token: Option<String>If present, indicates that more output is available than is
included in the current response. Use this value in the NextToken request parameter
in a subsequent call to the operation to get the next part of the output. You should repeat this
until the NextToken response element comes back as null.
Implementations
Creates a new builder-style object to manufacture ListGroupsOutput