#[non_exhaustive]pub struct GroupConfigurationBuilder { /* private fields */ }Expand description
A builder for GroupConfiguration.
Implementations
sourceimpl GroupConfigurationBuilder
impl GroupConfigurationBuilder
sourcepub fn configuration(self, input: GroupConfigurationItem) -> Self
pub fn configuration(self, input: GroupConfigurationItem) -> Self
Appends an item to configuration.
To override the contents of this collection use set_configuration.
The configuration currently associated with the group and in effect.
sourcepub fn set_configuration(
self,
input: Option<Vec<GroupConfigurationItem>>
) -> Self
pub fn set_configuration( self, input: Option<Vec<GroupConfigurationItem>> ) -> Self
The configuration currently associated with the group and in effect.
sourcepub fn get_configuration(&self) -> &Option<Vec<GroupConfigurationItem>>
pub fn get_configuration(&self) -> &Option<Vec<GroupConfigurationItem>>
The configuration currently associated with the group and in effect.
sourcepub fn proposed_configuration(self, input: GroupConfigurationItem) -> Self
pub fn proposed_configuration(self, input: GroupConfigurationItem) -> Self
Appends an item to proposed_configuration.
To override the contents of this collection use set_proposed_configuration.
If present, the new configuration that is in the process of being applied to the group.
sourcepub fn set_proposed_configuration(
self,
input: Option<Vec<GroupConfigurationItem>>
) -> Self
pub fn set_proposed_configuration( self, input: Option<Vec<GroupConfigurationItem>> ) -> Self
If present, the new configuration that is in the process of being applied to the group.
sourcepub fn get_proposed_configuration(&self) -> &Option<Vec<GroupConfigurationItem>>
pub fn get_proposed_configuration(&self) -> &Option<Vec<GroupConfigurationItem>>
If present, the new configuration that is in the process of being applied to the group.
sourcepub fn status(self, input: GroupConfigurationStatus) -> Self
pub fn status(self, input: GroupConfigurationStatus) -> Self
The current status of an attempt to update the group configuration.
sourcepub fn set_status(self, input: Option<GroupConfigurationStatus>) -> Self
pub fn set_status(self, input: Option<GroupConfigurationStatus>) -> Self
The current status of an attempt to update the group configuration.
sourcepub fn get_status(&self) -> &Option<GroupConfigurationStatus>
pub fn get_status(&self) -> &Option<GroupConfigurationStatus>
The current status of an attempt to update the group configuration.
sourcepub fn failure_reason(self, input: impl Into<String>) -> Self
pub fn failure_reason(self, input: impl Into<String>) -> Self
If present, the reason why a request to update the group configuration failed.
sourcepub fn set_failure_reason(self, input: Option<String>) -> Self
pub fn set_failure_reason(self, input: Option<String>) -> Self
If present, the reason why a request to update the group configuration failed.
sourcepub fn get_failure_reason(&self) -> &Option<String>
pub fn get_failure_reason(&self) -> &Option<String>
If present, the reason why a request to update the group configuration failed.
sourcepub fn build(self) -> GroupConfiguration
pub fn build(self) -> GroupConfiguration
Consumes the builder and constructs a GroupConfiguration.