#[non_exhaustive]pub struct GroupConfigurationItemBuilder { /* private fields */ }Expand description
A builder for GroupConfigurationItem.
Implementations
sourceimpl GroupConfigurationItemBuilder
impl GroupConfigurationItemBuilder
sourcepub fn type(self, input: impl Into<String>) -> Self
pub fn type(self, input: impl Into<String>) -> Self
Specifies the type of group configuration item. Each item must have a unique value for type. For the list of types that you can specify for a configuration item, see Supported resource types and parameters.
sourcepub fn set_type(self, input: Option<String>) -> Self
pub fn set_type(self, input: Option<String>) -> Self
Specifies the type of group configuration item. Each item must have a unique value for type. For the list of types that you can specify for a configuration item, see Supported resource types and parameters.
sourcepub fn get_type(&self) -> &Option<String>
pub fn get_type(&self) -> &Option<String>
Specifies the type of group configuration item. Each item must have a unique value for type. For the list of types that you can specify for a configuration item, see Supported resource types and parameters.
sourcepub fn parameters(self, input: GroupConfigurationParameter) -> Self
pub fn parameters(self, input: GroupConfigurationParameter) -> Self
Appends an item to parameters.
To override the contents of this collection use set_parameters.
A collection of parameters for this group configuration item. For the list of parameters that you can use with each configuration item type, see Supported resource types and parameters.
sourcepub fn set_parameters(
self,
input: Option<Vec<GroupConfigurationParameter>>
) -> Self
pub fn set_parameters( self, input: Option<Vec<GroupConfigurationParameter>> ) -> Self
A collection of parameters for this group configuration item. For the list of parameters that you can use with each configuration item type, see Supported resource types and parameters.
sourcepub fn get_parameters(&self) -> &Option<Vec<GroupConfigurationParameter>>
pub fn get_parameters(&self) -> &Option<Vec<GroupConfigurationParameter>>
A collection of parameters for this group configuration item. For the list of parameters that you can use with each configuration item type, see Supported resource types and parameters.
sourcepub fn build(self) -> Result<GroupConfigurationItem, BuildError>
pub fn build(self) -> Result<GroupConfigurationItem, BuildError>
Consumes the builder and constructs a GroupConfigurationItem.
This method will fail if any of the following fields are not set: