#[non_exhaustive]
pub struct GroupConfigurationParameterBuilder { /* private fields */ }
Implementations

source

impl GroupConfigurationParameterBuilder

source

pub fn name(self, input: impl Into<String>) -> Self

The name of the group configuration parameter. For the list of parameters that you can use with each configuration item type, see Supported resource types and parameters.

This field is required.
source

pub fn set_name(self, input: Option<String>) -> Self

The name of the group configuration parameter. For the list of parameters that you can use with each configuration item type, see Supported resource types and parameters.

source

pub fn get_name(&self) -> &Option<String>

The name of the group configuration parameter. For the list of parameters that you can use with each configuration item type, see Supported resource types and parameters.

source

pub fn values(self, input: impl Into<String>) -> Self

Appends an item to values.

To override the contents of this collection use set_values.

The value or values to be used for the specified parameter. For the list of values you can use with each parameter, see Supported resource types and parameters.

source

pub fn set_values(self, input: Option<Vec<String>>) -> Self

The value or values to be used for the specified parameter. For the list of values you can use with each parameter, see Supported resource types and parameters.

source

pub fn get_values(&self) -> &Option<Vec<String>>

The value or values to be used for the specified parameter. For the list of values you can use with each parameter, see Supported resource types and parameters.

source

pub fn build(self) -> Result<GroupConfigurationParameter, BuildError>

Consumes the builder and constructs a GroupConfigurationParameter. This method will fail if any of the following fields are not set: