#[non_exhaustive]pub struct ResourceIdentifierBuilder { /* private fields */ }Expand description
A builder for ResourceIdentifier.
Implementations
sourceimpl ResourceIdentifierBuilder
impl ResourceIdentifierBuilder
sourcepub fn resource_arn(self, input: impl Into<String>) -> Self
pub fn resource_arn(self, input: impl Into<String>) -> Self
The ARN of a resource.
sourcepub fn set_resource_arn(self, input: Option<String>) -> Self
pub fn set_resource_arn(self, input: Option<String>) -> Self
The ARN of a resource.
sourcepub fn get_resource_arn(&self) -> &Option<String>
pub fn get_resource_arn(&self) -> &Option<String>
The ARN of a resource.
sourcepub fn resource_type(self, input: impl Into<String>) -> Self
pub fn resource_type(self, input: impl Into<String>) -> Self
The resource type of a resource, such as AWS::EC2::Instance.
sourcepub fn set_resource_type(self, input: Option<String>) -> Self
pub fn set_resource_type(self, input: Option<String>) -> Self
The resource type of a resource, such as AWS::EC2::Instance.
sourcepub fn get_resource_type(&self) -> &Option<String>
pub fn get_resource_type(&self) -> &Option<String>
The resource type of a resource, such as AWS::EC2::Instance.
sourcepub fn build(self) -> ResourceIdentifier
pub fn build(self) -> ResourceIdentifier
Consumes the builder and constructs a ResourceIdentifier.