Struct aws_sdk_resourcegroups::types::AccountSettings
source · #[non_exhaustive]pub struct AccountSettings {
pub group_lifecycle_events_desired_status: Option<GroupLifecycleEventsDesiredStatus>,
pub group_lifecycle_events_status: Option<GroupLifecycleEventsStatus>,
pub group_lifecycle_events_status_message: Option<String>,
}Expand description
The Resource Groups settings for this Amazon Web Services account.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group_lifecycle_events_desired_status: Option<GroupLifecycleEventsDesiredStatus>The desired target status of the group lifecycle events feature. If
group_lifecycle_events_status: Option<GroupLifecycleEventsStatus>The current status of the group lifecycle events feature.
group_lifecycle_events_status_message: Option<String>The text of any error message occurs during an attempt to turn group lifecycle events on or off.
Implementations
sourceimpl AccountSettings
impl AccountSettings
sourcepub fn group_lifecycle_events_desired_status(
&self
) -> Option<&GroupLifecycleEventsDesiredStatus>
pub fn group_lifecycle_events_desired_status( &self ) -> Option<&GroupLifecycleEventsDesiredStatus>
The desired target status of the group lifecycle events feature. If
sourcepub fn group_lifecycle_events_status(
&self
) -> Option<&GroupLifecycleEventsStatus>
pub fn group_lifecycle_events_status( &self ) -> Option<&GroupLifecycleEventsStatus>
The current status of the group lifecycle events feature.
sourcepub fn group_lifecycle_events_status_message(&self) -> Option<&str>
pub fn group_lifecycle_events_status_message(&self) -> Option<&str>
The text of any error message occurs during an attempt to turn group lifecycle events on or off.
sourceimpl AccountSettings
impl AccountSettings
sourcepub fn builder() -> AccountSettingsBuilder
pub fn builder() -> AccountSettingsBuilder
Creates a new builder-style object to manufacture AccountSettings.