Struct aws_sdk_resourcegroups::types::FailedResource
source · #[non_exhaustive]pub struct FailedResource {
pub resource_arn: Option<String>,
pub error_message: Option<String>,
pub error_code: Option<String>,
}Expand description
A resource that failed to be added to or removed from a group.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_arn: Option<String>The ARN of the resource that failed to be added or removed.
error_message: Option<String>The error message text associated with the failure.
error_code: Option<String>The error code associated with the failure.
Implementations
sourceimpl FailedResource
impl FailedResource
sourcepub fn resource_arn(&self) -> Option<&str>
pub fn resource_arn(&self) -> Option<&str>
The ARN of the resource that failed to be added or removed.
sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
The error message text associated with the failure.
sourcepub fn error_code(&self) -> Option<&str>
pub fn error_code(&self) -> Option<&str>
The error code associated with the failure.
sourceimpl FailedResource
impl FailedResource
sourcepub fn builder() -> FailedResourceBuilder
pub fn builder() -> FailedResourceBuilder
Creates a new builder-style object to manufacture FailedResource.