#[non_exhaustive]
pub struct Group { pub group_arn: String, pub name: String, pub description: Option<String>, }
A resource group that contains Amazon Web Services resources. You can assign resources to the group by associating either of the following elements with the group:

  • ResourceQuery - Use a resource query to specify a set of tag keys and values. All resources in the same Amazon Web Services Region and Amazon Web Services account that have those keys with the same values are included in the group. You can add a resource query when you create the group, or later by using the PutGroupConfiguration operation.

  • GroupConfiguration - Use a service configuration to associate the group with an Amazon Web Services service. The configuration specifies which resource types can be included in the group.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
group_arn: String

The ARN of the resource group.

name: String

The name of the resource group.

description: Option<String>

The description of the resource group.

Implementations

source

impl Group

source

pub fn group_arn(&self) -> &str

The ARN of the resource group.

source

pub fn name(&self) -> &str

The name of the resource group.

source

pub fn description(&self) -> Option<&str>

The description of the resource group.

source

impl Group

source

pub fn builder() -> GroupBuilder

Creates a new builder-style object to manufacture Group.