#[non_exhaustive]pub struct GroupConfigurationItem {
pub type: String,
pub parameters: Option<Vec<GroupConfigurationParameter>>,
}Expand description
An item in a group configuration. A group service configuration can have one or more items. For details about group service configuration syntax, see Service configurations for resource groups.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: StringSpecifies the type of group configuration item. Each item must have a unique value for type. For the list of types that you can specify for a configuration item, see Supported resource types and parameters.
parameters: Option<Vec<GroupConfigurationParameter>>A collection of parameters for this group configuration item. For the list of parameters that you can use with each configuration item type, see Supported resource types and parameters.
Implementations
sourceimpl GroupConfigurationItem
impl GroupConfigurationItem
sourcepub fn type(&self) -> &str
pub fn type(&self) -> &str
Specifies the type of group configuration item. Each item must have a unique value for type. For the list of types that you can specify for a configuration item, see Supported resource types and parameters.
sourcepub fn parameters(&self) -> &[GroupConfigurationParameter]
pub fn parameters(&self) -> &[GroupConfigurationParameter]
A collection of parameters for this group configuration item. For the list of parameters that you can use with each configuration item type, see Supported resource types and parameters.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .parameters.is_none().
sourceimpl GroupConfigurationItem
impl GroupConfigurationItem
sourcepub fn builder() -> GroupConfigurationItemBuilder
pub fn builder() -> GroupConfigurationItemBuilder
Creates a new builder-style object to manufacture GroupConfigurationItem.