#[non_exhaustive]
pub struct GroupConfigurationParameter { pub name: Option<String>, pub values: Option<Vec<String>>, }
A parameter for a group configuration item. For details about group service configuration syntax, see Service configurations for resource groups.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: Option<String>

The name of the group configuration parameter. For the list of parameters that you can use with each configuration item type, see Supported resource types and parameters.

values: Option<Vec<String>>

The value or values to be used for the specified parameter. For the list of values you can use with each parameter, see Supported resource types and parameters.

Implementations

source

impl GroupConfigurationParameter

source

pub fn name(&self) -> Option<&str>

The name of the group configuration parameter. For the list of parameters that you can use with each configuration item type, see Supported resource types and parameters.

source

pub fn values(&self) -> Option<&[String]>

The value or values to be used for the specified parameter. For the list of values you can use with each parameter, see Supported resource types and parameters.

source

impl GroupConfigurationParameter

source

pub fn builder() -> GroupConfigurationParameterBuilder

Creates a new builder-style object to manufacture GroupConfigurationParameter.