Struct aws_sdk_resourcegroups::types::QueryError
source · #[non_exhaustive]pub struct QueryError {
pub error_code: Option<QueryErrorCode>,
pub message: Option<String>,
}Expand description
A two-part error structure that can occur in ListGroupResources or SearchResources operations on CloudFront stack-based queries. The error occurs if the CloudFront stack on which the query is based either does not exist, or has a status that renders the stack inactive. A QueryError occurrence does not necessarily mean that Resource Groups could not complete the operation, but the resulting group might have no member resources.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.error_code: Option<QueryErrorCode>Specifies the error code that was raised.
message: Option<String>A message that explains the ErrorCode value. Messages might state that the specified CloudFront stack does not exist (or no longer exists). For CLOUDFORMATION_STACK_INACTIVE, the message typically states that the CloudFront stack has a status that is not (or no longer) active, such as CREATE_FAILED.
Implementations
sourceimpl QueryError
impl QueryError
sourcepub fn error_code(&self) -> Option<&QueryErrorCode>
pub fn error_code(&self) -> Option<&QueryErrorCode>
Specifies the error code that was raised.
sourcepub fn message(&self) -> Option<&str>
pub fn message(&self) -> Option<&str>
A message that explains the ErrorCode value. Messages might state that the specified CloudFront stack does not exist (or no longer exists). For CLOUDFORMATION_STACK_INACTIVE, the message typically states that the CloudFront stack has a status that is not (or no longer) active, such as CREATE_FAILED.
sourceimpl QueryError
impl QueryError
sourcepub fn builder() -> QueryErrorBuilder
pub fn builder() -> QueryErrorBuilder
Creates a new builder-style object to manufacture QueryError.