Enum aws_sdk_resourcegroups::error::GroupResourcesErrorKind [−][src]
#[non_exhaustive]
pub enum GroupResourcesErrorKind {
BadRequestException(BadRequestException),
ForbiddenException(ForbiddenException),
InternalServerErrorException(InternalServerErrorException),
MethodNotAllowedException(MethodNotAllowedException),
NotFoundException(NotFoundException),
TooManyRequestsException(TooManyRequestsException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the GroupResources operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BadRequestException(BadRequestException)The request includes one or more parameters that violate validation rules.
Tuple Fields of BadRequestException
ForbiddenException(ForbiddenException)The caller isn't authorized to make the request. Check permissions.
Tuple Fields of ForbiddenException
InternalServerErrorException(InternalServerErrorException)An internal error occurred while processing the request. Try again later.
Tuple Fields of InternalServerErrorException
MethodNotAllowedException(MethodNotAllowedException)The request uses an HTTP method that isn't allowed for the specified resource.
Tuple Fields of MethodNotAllowedException
NotFoundException(NotFoundException)One or more of the specified resources don't exist.
Tuple Fields of NotFoundException
TooManyRequestsException(TooManyRequestsException)You've exceeded throttling limits by making too many requests in a period of time.
Tuple Fields of TooManyRequestsException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code