Struct aws_sdk_resourcegroups::input::create_group_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CreateGroupInput
Implementations
The name of the group, which is the identifier of the group in other operations. You
can't change the name of a resource group after you create it. A resource group name can
consist of letters, numbers, hyphens, periods, and underscores. The name cannot start
with AWS or aws; these are reserved. A resource group name
must be unique within each AWS Region in your AWS account.
The name of the group, which is the identifier of the group in other operations. You
can't change the name of a resource group after you create it. A resource group name can
consist of letters, numbers, hyphens, periods, and underscores. The name cannot start
with AWS or aws; these are reserved. A resource group name
must be unique within each AWS Region in your AWS account.
The description of the resource group. Descriptions can consist of letters, numbers, hyphens, underscores, periods, and spaces.
The description of the resource group. Descriptions can consist of letters, numbers, hyphens, underscores, periods, and spaces.
The resource query that determines which AWS resources are members of this group. For more information about resource queries, see Create a tag-based group in Resource Groups.
A resource group can contain either a ResourceQuery or a
Configuration, but not both.
The resource query that determines which AWS resources are members of this group. For more information about resource queries, see Create a tag-based group in Resource Groups.
A resource group can contain either a ResourceQuery or a
Configuration, but not both.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tags to add to the group. A tag is key-value pair string.
The tags to add to the group. A tag is key-value pair string.
Appends an item to configuration.
To override the contents of this collection use set_configuration.
A configuration associates the resource group with an AWS service and specifies how the service can interact with the resources in the group. A configuration is an array of GroupConfigurationItem elements. For details about the syntax of service configurations, see Service configurations for resource groups.
A resource group can contain either a Configuration or a
ResourceQuery, but not both.
A configuration associates the resource group with an AWS service and specifies how the service can interact with the resources in the group. A configuration is an array of GroupConfigurationItem elements. For details about the syntax of service configurations, see Service configurations for resource groups.
A resource group can contain either a Configuration or a
ResourceQuery, but not both.
Consumes the builder and constructs a CreateGroupInput