Struct aws_sdk_resourcegroups::model::query_error::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for QueryError
Implementations
Possible values are CLOUDFORMATION_STACK_INACTIVE and
CLOUDFORMATION_STACK_NOT_EXISTING.
Possible values are CLOUDFORMATION_STACK_INACTIVE and
CLOUDFORMATION_STACK_NOT_EXISTING.
A message that explains the ErrorCode value. Messages might state that
the specified CloudFormation stack does not exist (or no longer exists). For
CLOUDFORMATION_STACK_INACTIVE, the message typically states that the
CloudFormation stack has a status that is not (or no longer) active, such as
CREATE_FAILED.
A message that explains the ErrorCode value. Messages might state that
the specified CloudFormation stack does not exist (or no longer exists). For
CLOUDFORMATION_STACK_INACTIVE, the message typically states that the
CloudFormation stack has a status that is not (or no longer) active, such as
CREATE_FAILED.
Consumes the builder and constructs a QueryError