Struct aws_sdk_resourcegroups::model::QueryError [−][src]
#[non_exhaustive]pub struct QueryError {
pub error_code: Option<QueryErrorCode>,
pub message: Option<String>,
}Expand description
A two-part error structure that can occur in ListGroupResources or
SearchResources operations on CloudFormation stack-based queries. The error
occurs if the CloudFormation stack on which the query is based either does not exist, or has a
status that renders the stack inactive. A QueryError occurrence does not
necessarily mean that AWS Resource Groups could not complete the operation, but the resulting
group might have no member resources.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.error_code: Option<QueryErrorCode>Possible values are CLOUDFORMATION_STACK_INACTIVE and
CLOUDFORMATION_STACK_NOT_EXISTING.
message: Option<String>A message that explains the ErrorCode value. Messages might state that
the specified CloudFormation stack does not exist (or no longer exists). For
CLOUDFORMATION_STACK_INACTIVE, the message typically states that the
CloudFormation stack has a status that is not (or no longer) active, such as
CREATE_FAILED.
Implementations
Possible values are CLOUDFORMATION_STACK_INACTIVE and
CLOUDFORMATION_STACK_NOT_EXISTING.
A message that explains the ErrorCode value. Messages might state that
the specified CloudFormation stack does not exist (or no longer exists). For
CLOUDFORMATION_STACK_INACTIVE, the message typically states that the
CloudFormation stack has a status that is not (or no longer) active, such as
CREATE_FAILED.
Creates a new builder-style object to manufacture QueryError