Struct aws_sdk_resourcegroups::operation::get_group_query::builders::GetGroupQueryFluentBuilder
source · pub struct GetGroupQueryFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetGroupQuery.
Retrieves the resource query associated with the specified resource group. For more information about resource queries, see Create a tag-based group in Resource Groups.
Minimum permissions
To run this command, you must have the following permissions:
-
resource-groups:GetGroupQuery
Implementations
sourceimpl GetGroupQueryFluentBuilder
impl GetGroupQueryFluentBuilder
sourcepub fn as_input(&self) -> &GetGroupQueryInputBuilder
pub fn as_input(&self) -> &GetGroupQueryInputBuilder
Access the GetGroupQuery as a reference.
sourcepub async fn send(
self
) -> Result<GetGroupQueryOutput, SdkError<GetGroupQueryError, HttpResponse>>
pub async fn send( self ) -> Result<GetGroupQueryOutput, SdkError<GetGroupQueryError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn customize(
self
) -> CustomizableOperation<GetGroupQueryOutput, GetGroupQueryError, Self>
pub fn customize( self ) -> CustomizableOperation<GetGroupQueryOutput, GetGroupQueryError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
sourcepub fn group_name(self, input: impl Into<String>) -> Self
👎Deprecated: This field is deprecated, use Group instead.
pub fn group_name(self, input: impl Into<String>) -> Self
Don't use this parameter. Use Group instead.
sourcepub fn set_group_name(self, input: Option<String>) -> Self
👎Deprecated: This field is deprecated, use Group instead.
pub fn set_group_name(self, input: Option<String>) -> Self
Don't use this parameter. Use Group instead.
sourcepub fn get_group_name(&self) -> &Option<String>
👎Deprecated: This field is deprecated, use Group instead.
pub fn get_group_name(&self) -> &Option<String>
Don't use this parameter. Use Group instead.
sourcepub fn group(self, input: impl Into<String>) -> Self
pub fn group(self, input: impl Into<String>) -> Self
The name or the ARN of the resource group to query.