#[non_exhaustive]pub struct GroupConfigurationParameterBuilder { /* private fields */ }Expand description
A builder for GroupConfigurationParameter.
Implementations
sourceimpl GroupConfigurationParameterBuilder
impl GroupConfigurationParameterBuilder
sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the group configuration parameter. For the list of parameters that you can use with each configuration item type, see Supported resource types and parameters.
sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The name of the group configuration parameter. For the list of parameters that you can use with each configuration item type, see Supported resource types and parameters.
sourcepub fn get_name(&self) -> &Option<String>
pub fn get_name(&self) -> &Option<String>
The name of the group configuration parameter. For the list of parameters that you can use with each configuration item type, see Supported resource types and parameters.
sourcepub fn values(self, input: impl Into<String>) -> Self
pub fn values(self, input: impl Into<String>) -> Self
Appends an item to values.
To override the contents of this collection use set_values.
The value or values to be used for the specified parameter. For the list of values you can use with each parameter, see Supported resource types and parameters.
sourcepub fn set_values(self, input: Option<Vec<String>>) -> Self
pub fn set_values(self, input: Option<Vec<String>>) -> Self
The value or values to be used for the specified parameter. For the list of values you can use with each parameter, see Supported resource types and parameters.
sourcepub fn get_values(&self) -> &Option<Vec<String>>
pub fn get_values(&self) -> &Option<Vec<String>>
The value or values to be used for the specified parameter. For the list of values you can use with each parameter, see Supported resource types and parameters.
sourcepub fn build(self) -> GroupConfigurationParameter
pub fn build(self) -> GroupConfigurationParameter
Consumes the builder and constructs a GroupConfigurationParameter.