Struct aws_sdk_resourcegroups::types::Group
source · #[non_exhaustive]pub struct Group {
pub group_arn: String,
pub name: String,
pub description: Option<String>,
}Expand description
A resource group that contains Amazon Web Services resources. You can assign resources to the group by associating either of the following elements with the group:
-
ResourceQuery- Use a resource query to specify a set of tag keys and values. All resources in the same Amazon Web Services Region and Amazon Web Services account that have those keys with the same values are included in the group. You can add a resource query when you create the group, or later by using thePutGroupConfigurationoperation. -
GroupConfiguration- Use a service configuration to associate the group with an Amazon Web Services service. The configuration specifies which resource types can be included in the group.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group_arn: StringThe ARN of the resource group.
name: StringThe name of the resource group.
description: Option<String>The description of the resource group.