#[non_exhaustive]
pub struct GroupConfiguration { pub configuration: Option<Vec<GroupConfigurationItem>>, pub proposed_configuration: Option<Vec<GroupConfigurationItem>>, pub status: Option<GroupConfigurationStatus>, pub failure_reason: Option<String>, }
A service configuration associated with a resource group. The configuration options are determined by the Amazon Web Services service that defines the Type, and specifies which resources can be included in the group. You can add a service configuration when you create the group by using CreateGroup, or later by using the PutGroupConfiguration operation. For details about group service configuration syntax, see Service configurations for resource groups.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
configuration: Option<Vec<GroupConfigurationItem>>

The configuration currently associated with the group and in effect.

proposed_configuration: Option<Vec<GroupConfigurationItem>>

If present, the new configuration that is in the process of being applied to the group.

status: Option<GroupConfigurationStatus>

The current status of an attempt to update the group configuration.

failure_reason: Option<String>

If present, the reason why a request to update the group configuration failed.

Implementations

source

impl GroupConfiguration

source

pub fn configuration(&self) -> Option<&[GroupConfigurationItem]>

The configuration currently associated with the group and in effect.

source

pub fn proposed_configuration(&self) -> Option<&[GroupConfigurationItem]>

If present, the new configuration that is in the process of being applied to the group.

source

pub fn status(&self) -> Option<&GroupConfigurationStatus>

The current status of an attempt to update the group configuration.

source

pub fn failure_reason(&self) -> Option<&str>

If present, the reason why a request to update the group configuration failed.

source

impl GroupConfiguration

source

pub fn builder() -> GroupConfigurationBuilder

Creates a new builder-style object to manufacture GroupConfiguration.